Auxiliary functions that help automate the process of random number generation or pdf, survival function or hazard rate functions
RdistSwitch(dist, SampleSize, par1, par2)
PdfSwitch(xout, dist, par1, par2)
CdfSwitch(xout, dist, par1, par2)
HazardRate(xout, dist, par1, par2)A string. Corresponds to one of weibull, lognorm, chisquare, exponential, binomial, geometric, poisson, negativebinomial, uniform
The size of the random sample to be drawn
Grid points where the function will be evaluated
parameter 1 of the distirbution
parameter 2 of the distirbution
A vector with the values of the function at the designated points xout or the random numbers drawn.
Implements random number generation and density, survival and hazard rate estimates for several distributions. These functions are mainly used when simulating the mean square error etc from known distributions.