Privides the various hazard rate function derivatives and related functionals with reference to the Weibull function
l1(x,p,l)
l2(x,p,l)
l3(x,p,l)
l4(x,p,l)
lw(x,p,l)
lwF(x,p,l)
gx(x,p,l)A vector of points at which the hazard rate function will be estimated.
MLE estimate of the shape parameter
MLE estimate of the scale parameter
A vector with the values of the function at the designated points x.
Implements the necessary functions for calculating the squared bias term of the variable bandwidth estimate.