Auxiliary functions for discrete semiparametric and kernel smooth hazard rate estimation
nsf(xin, cens, xout)
Tm(tk, xout, distribution, par1, par2)
CparamCalculation(gamparam, VehHazard)
power.matrix(M, n)
base(m, b)
SmoothedEstimate(NonParEst, VehHazard, gammapar, SCproduct, Cpar)A vector of data points. Missing values not allowed.
A vector of 1s and zeros, 1's indicate uncensored observations, 0's correspond to censored obs.
The points where the estimate should be calculated.
desing points for the NPMLE estimate.
which distribution to use?
distribution parameter 1
distribution parameter 2
gamma parameter
a matrix to be raised to a power
the power the matrix will be raised at
express m as a power of b
express m as a power of b
The crude nonparametric hazard rate estimate.
Vehicle hazard rate
gamma parameter
SC product, the result of DetermineSCprod
C parameter, the result of CparamCalculation.
A vector with the values of the hazard rate estimates.
Auxiliary functions for discrete hazard rate estimators. The function nsf is used for the kernel smooth estimate TutzPritscher.
Tm used to calculate \(\max(t_k; 1-\sum_{l=0}^k \eta_l > \epsilon), \epsilon>0\) in the implementation of the semiparametric estimate
CparamCalculationreturns the C smoothing parameter calculated as \(C= \gamma/\max_{k \geq 0} ( \lambda(t_{k-1}) + \lambda(t_k) + \lambda(t_{k+1}) )\)
DetermineSCprodthis finds \(SC = \gamma((n+1) \hat B_1)^{-1} \hat V_1\) n = number of obs, gammapar = sum of vehicle haz at xout (computed elsewhere)