Learn R Programming

NPHazardRate (version 0.1)

sn.i, tn.i: Local kernel weights

Description

Implements the local kernel weights which are used in the implementation of LocLinEst and the second derivative estimate used in PlugInBand.

Usage

sn.0(xin, xout, h, kfun)
sn.1(xin, xout, h, kfun)
sn.2(xin, xout, h, kfun)
sn.3(xin, xout, h, kfun)
sn.4(xin, xout, h, kfun)
sn.5(xin, xout, h, kfun)
sn.6(xin, xout, h, kfun)
tn.0(xin, xout, h, kfun, Y)
tn.1(xin, xout, h, kfun, Y)
tn.2(xin, xout, h, kfun, Y)
tn.3(xin, xout, h, kfun, Y)

Arguments

xin

A vector of data points, typicaly these are the bin centers. Missing values not allowed.

xout

A vector of data points where the estimate will be evaluated.

h

A scalar. The bandwidth to use.

kfun

The kernel function to use.

Y

Empirical hazard rate estimates.

Value

The weight of the functional at \(x\)

Details

The functions calculate the quantities $$S_{n,l}(x) = \sum_{i=1}^n K \left (\frac{x_i-x}{h}\right ) (x_i-x)^l, l=0,\dots,6 $$ and $$T_{n,l}(x) = \sum_{i=1}^n K \left (\frac{x_i-x}{h}\right ) (x_i-x)^l Y_i, l=0,\dots,3$$ These qunatities are used to adjust the hazard rate estimate and its second derivative in the boundary.

References

  1. Bagkavos and Patil, Local Polynomial Fitting in Failure Rate Estimation, IEEE Transactions on Reliability, 57, (2008),

  2. Bagkavos (2011), Annals of the Institute of Statistical Mathematics, 63(5), 1019-1046.