Implements the local kernel weights which are used in the implementation of LocLinEst and the second derivative estimate used in PlugInBand.
sn.0(xin, xout, h, kfun)
sn.1(xin, xout, h, kfun)
sn.2(xin, xout, h, kfun)
sn.3(xin, xout, h, kfun)
sn.4(xin, xout, h, kfun)
sn.5(xin, xout, h, kfun)
sn.6(xin, xout, h, kfun)
tn.0(xin, xout, h, kfun, Y)
tn.1(xin, xout, h, kfun, Y)
tn.2(xin, xout, h, kfun, Y)
tn.3(xin, xout, h, kfun, Y)A vector of data points, typicaly these are the bin centers. Missing values not allowed.
A vector of data points where the estimate will be evaluated.
A scalar. The bandwidth to use.
The kernel function to use.
Empirical hazard rate estimates.
The weight of the functional at \(x\)
The functions calculate the quantities $$S_{n,l}(x) = \sum_{i=1}^n K \left (\frac{x_i-x}{h}\right ) (x_i-x)^l, l=0,\dots,6 $$ and $$T_{n,l}(x) = \sum_{i=1}^n K \left (\frac{x_i-x}{h}\right ) (x_i-x)^l Y_i, l=0,\dots,3$$ These qunatities are used to adjust the hazard rate estimate and its second derivative in the boundary.